<?php

class Library extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'Library':
	 * @var integer $id
	 * @var string $name
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Library';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		return array(
			array('name','length','max'=>40),
			array('name', 'required'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'books' => array(self::MANY_MANY, 'Book', 'LibraryBook(libraryID, bookISBN)'),
			'services' => array(self::MANY_MANY, 'Service', 'LibraryService(libraryID, serviceID)'),
			'libraryBooks'=>array(self::HAS_MANY, 'LibraryBook', 'libraryID'),
			'libraryComments'=>array(self::HAS_MANY, 'LibraryComment', 'libraryID'),
		);
	}
	
	public function behaviors(){
		return array(
			'CSaveRelationsBehavior' => array(
				'class' => 'CSaveRelationsBehavior',
				'relations' => array(
					'libraryBooks'=>array("message"=>"Please, check the books"),
					'services'=>array("message"=>"Please, check the services")
				)
			)
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'Id',
			'name' => 'Name',
			'libraryBooks' => 'Available books',
			'services' => 'Available services'
		);
	}
	
	public function addBook() {
		$this->addRelatedRecord('libraryBooks',new LibraryBook,true);
	}

	public function deleteBook($idx) {
		$libraryBookArray = $this->libraryBooks;
		unset($libraryBookArray[$idx]);
		$this->libraryBooks = $libraryBookArray;
	}
	
	public function addComment() {
		$this->addRelatedRecord('libraryComments',new LibraryComment,true);
	}

	public function deleteComment($idx) {
		$libraryCommentsArray = $this->libraryComments;
		unset($libraryCommentsArray[$idx]);
		$this->libraryComments = $libraryCommentsArray;
	}
}